%ROTY   Rotation about y
% Homogeneous transform for rotation about y axis
%
% Syntax:  T = roty(phi)
%
% Inputs:
%    phi - angle to rotate about y
%
% Outputs:
%    T - homogeneous rotation transformation
%
% See also: ROTX,  ROTZ

% Author: Travis Hydzik
% Last revision: 19 October 2004

function T = roty(phi)
	
	T = [ cos(phi)    0  sin(phi)    0 
             0        1     0        0
         -sin(phi)    0  cos(phi)    0 
             0        0     0        1];

% alternatively
% T = rot([0 1 0], phi)